Capture

Struct Capture 

pub struct Capture<T> { /* private fields */ }
Capture TCP packets on an interface

Implementations

Source

impl Capture<Ready>

pub fn new(filter: Box<dyn Filter>, interface: Option<String>) -> Self

Create a new Capture struct with a filter and interface to capture on

This simply sets up a struct without actually starting to capture.

pub fn start(self) -> Result<Capture<Capturing>, CaptureError>

Start capturing packets

This method will consume the object and return a new one.

Errors

Will return an error if something goes wrong with creating the socket or joining a thread after a socket error has occurred.

Source

impl Capture<Capturing>

pub fn end(self) -> Result<Vec<IpPacket>, CaptureError>

Stop capturing packets and get captured packets

This will signal each thread to stop and get the captured packets.

Errors

If there is an error in joining the thread that stores the packets, an error will be returned. No error in joining the snooping thread will be returned as long as the store thread returns properly.