DataType

Enum DataType 

#[non_exhaustive]
pub enum DataType { TCP(TcpPacket), UDP(UdpDatagram), }
Data that the IP packet encapsulates

An IP packet can encapsulate many different types of data. Each possible encapsulated type that this library supports is represented by this enum.

This enum is marked as non-exhaustive as more underlying types may be added in future versions of the library.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.

Implementations

Source

impl DataType

pub fn pcap_write<W: Write>(&self, f: &mut W) -> Result<()>

Write the underlying protocol data to the pcap file

Errors

Will return any io errors that occur

pub fn get_proto_num(&self) -> u8

pub fn get_payload(&self) -> &Vec<u8>