TcpPacket

Struct TcpPacket 

pub struct TcpPacket {
    pub source: u16,
    pub dest: u16,
    pub seq: u32,
    pub ack: u32,
    pub flags: TcpFlags,
    pub window: u16,
    pub checksum: u16,
    pub urg: u16,
    pub option_data: Option<Vec<u8>>,
    pub data: Vec<u8>,
}
TCP header and its associated data

Fields

source: u16

Source port

dest: u16

Destination port

seq: u32

Sequence number

ack: u32

Acknowledge number

flags: TcpFlags

TCP flags such as reset, ack, push, etc.

window: u16

Window size

checksum: u16

Checksum value

urg: u16

Urgent pointer

option_data: Option<Vec<u8>>

Option data if there was any

data: Vec<u8>

TCP data

Implementations

Source

impl TcpPacket

pub fn parse_from_bytes(data: &dyn AsRef<[u8]>) -> Result<Self, TcpParseErr>

Parse a TCP packet and data out of a stream of bytes

This method is meant to be called from the IpPacket::parse_from_bytes method.

Errors

Returns an error if there are not enough bytes for a valid TCP packet.

pub fn pcap_write<W: Write>(&self, file: &mut W) -> Result<()>

Write packet to a pcap file

Writes a tcp packet to a pcap file. This is for use by the write_pcap_file function.

Errors

Will return an error if any of the writes fail.