UdpDatagram

Struct UdpDatagram 

pub struct UdpDatagram {
    pub source: u16,
    pub dest: u16,
    pub checksum: u16,
    pub payload: Vec<u8>,
}
UDP header and associated data

Fields

source: u16

Source port

dest: u16

Destination port

checksum: u16

Packet checksum

payload: Vec<u8>

UDP data

Implementations

Source

impl UdpDatagram

pub fn parse_from_bytes(data: &dyn AsRef<[u8]>) -> Result<Self, UdpParseErr>

Parse a udp packet from a slice of bytes

This method will not check the checksum.

Errors

This method will return an error if the slice is less than 8 bytes or if the size of the length field is larger than the length of the slice.

pub fn pcap_write<W: Write>(&self, f: &mut W) -> Result<()>

Write packet to a pcap file

Errors

Will return any io errors that occur.