pub struct Capture<T> { /* private fields */ }Expand description
Capture TCP packets on an interface
Implementations
Sourceimpl Capture<Ready>
impl Capture<Ready>
Sourceimpl Capture<Capturing>
impl Capture<Capturing>
Sourcepub fn end(self) -> Result<Vec<IpPacket>, CaptureError>
pub fn end(self) -> Result<Vec<IpPacket>, CaptureError>
Stop capturing packets and get captured packets
This will signal each thread to stop and get the captured packets.
Errors
If there is an error in joining the thread that stores the packets, an error will be returned. No error in joining the snooping thread will be returned as long as the store thread returns properly.