pub struct UdpDatagram {
pub source: u16,
pub dest: u16,
pub checksum: u16,
pub payload: Vec<u8>,
}Expand description
UDP header and associated data
Fields
source: u16Source port
dest: u16Destination port
checksum: u16Packet checksum
payload: Vec<u8>UDP data
Implementations
Sourceimpl UdpDatagram
impl UdpDatagram
Sourcepub fn parse_from_bytes(data: &dyn AsRef<[u8]>) -> Result<Self, UdpParseErr>
pub fn parse_from_bytes(data: &dyn AsRef<[u8]>) -> Result<Self, UdpParseErr>
Parse a udp packet from a slice of bytes
This method will not check the checksum.
Errors
This method will return an error if the slice is less than 8 bytes or if the size of the length field is larger than the length of the slice.